@@ -1,4 +1,3 @@
-require 'ap' # awesome_print gem
 require 'stringio'
 require 'gherkin/formatter/json_formatter'
 require 'gherkin/listener/formatter_listener'
@@ -12,15 +11,18 @@ class Hash
 end
 
 Given /^a JSON formatter$/ do
-  @io = StringIO.new
-  @formatter = Gherkin::Formatter::JSONFormatter.new(@io)
+  @out = StringIO.new
+  @formatter = Gherkin::Formatter::JSONFormatter.new(@out)
 end
 
 Then /^the outputted JSON should be:$/ do |expected_json|
   require 'json'
-  puts JSON.pretty_generate(JSON.parse(@io.string))
-  expected = JSON.parse(expected_json).ai
-  actual   = JSON.parse(@io.string).ai
+  @formatter.done
+  actual_json = @out.string
+  puts actual_json
+  puts JSON.pretty_generate(JSON.parse(actual_json))
+  expected = JSON.parse(expected_json)
+  actual   = JSON.parse(actual_json)
   actual.should == expected
 end
 
