@@ -1,3 +1,8 @@
+if RUBY_VERSION =~ /1.9/
+  Encoding.default_external = Encoding::UTF_8
+  Encoding.default_internal = Encoding::UTF_8
+end
+
 require 'rubygems'
 require 'bundler'
 Bundler.setup
@@ -9,7 +14,6 @@ end
 require 'gherkin'
 require 'gherkin/sexp_recorder'
 require 'gherkin/output_stream_string_io'
-require 'gherkin/java_libs'
 
 module TransformHelpers
   def tr_line_number(step_arg)
