@@ -1,7 +1,7 @@
 require 'v8'
 
 module Gherkin
-  # Thin adapter for the Javascript lexer, primarily used for testing.
+  # Thin adapter for the JavaScript lexer, primarily used for testing.
   class JsLexer
     def self.[](i18n_underscored_iso_code)
       cxt = V8::Context.new
@@ -13,8 +13,8 @@ module Gherkin
         p a
       end
 
-      cxt.load(File.dirname(__FILE__) + "/../../js/lib/gherkin/lexer/#{i18n_underscored_iso_code}.js")
+      cxt.load(File.dirname(__FILE__) + "/../../js/lib/gherkin/lexer/#{i18n_underscored_iso_code}.min.js")
       cxt['exports']['Lexer']
     end
   end
-end
\ No newline at end of file
+end
