@@ -10,7 +10,7 @@ module Gherkin
           o.map{|e| rubify(e)}
         when Java.gherkin.formatter.model.DocString
           require 'gherkin/formatter/model'
-          Formatter::Model::DocString.new(o.value, o.line)
+          Formatter::Model::DocString.new(o.content_type, o.value, o.line)
         else
           o
         end
