@@ -1,3 +1,8 @@
+if RUBY_VERSION =~ /1.9/
+  Encoding.default_external = Encoding::UTF_8
+  Encoding.default_internal = Encoding::UTF_8
+end
+
 require 'rubygems'
 require 'bundler'
 Bundler.setup
@@ -7,7 +12,6 @@ require 'gherkin'
 require 'stringio'
 require 'gherkin/sexp_recorder'
 require 'gherkin/output_stream_string_io'
-require 'gherkin/java_libs'
 require 'gherkin/shared/bom_group'
 require 'gherkin/shared/lexer_group'
 require 'gherkin/shared/tags_group'
